import { describe, expect, it } from "vitest";
import { getBuild, matchSnapshot } from "./utils";

describe("attr", () => {
  const compileESBuild = getBuild("attr");

  it("supports grouped array css attribute", async () => {
    const { files } = await compileESBuild({
      clsx: "emotion",
      expectFiles: 2,
      javascript: /* tsx */ `
        export function Hello() {
          return (
            <div css={["text-center", { hover: "font-semibold" }]}>
              Hello, world!
            </div>
          );
        }
      `,
    });

    matchSnapshot(files);
  });

  it('supports conditional expression in "css" attribute', async () => {
    const { files } = await compileESBuild({
      clsx: "emotion",
      expectFiles: 2,
      javascript: /* tsx */ `
        export function Hello({ isCenter }) {
          return (
            <div css={isCenter ? "text-center" : undefined}>
              Hello, world!
            </div>
          );
        }
      `,
    });

    matchSnapshot(files);
  });
});
